@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -18,38 +18,40 @@
    EXTERNAL ROUTINES/VARIABLES:
 
  ***************************************************************************/
-
-#ifdef OLD_HEADER_FILENAME
-#include <iostream.h>
-#else
 #include <iostream>
-#endif
 using std::cerr;
 using std::endl;
 
 #include <string>
-#include "H5Cpp.h"      // C++ API header file
+#include "H5Cpp.h" // C++ API header file
 using namespace H5;
 
-#include "h5cpputil.h"  // C++ utilility header file
+#include "h5test.h"
+#include "h5cpputil.h" // C++ utilility header file
 
 // Data file used in most test functions
 const H5std_string FILENAME("tvlstr.h5");
 
 // 1-D dataset with fixed dimensions
-const int SPACE1_RANK = 1;
+const int     SPACE1_RANK = 1;
 const hsize_t SPACE1_DIM1 = 4;
 
-/****************************************************************
-**
-**  test_vlstr_alloc_custom(): Test VL datatype custom memory
-**      allocation routines.  This routine just uses malloc to
-**      allocate the memory and increments the amount of memory
-**      allocated.  It is passed into setVlenMemManager.
-**
-**  Note: exact copy from the C version.
-**  (Not used now)
-****************************************************************/
+/*-------------------------------------------------------------------------
+ * Function:    test_vlstr_alloc_custom
+ *
+ * Purpose      Test VL datatype custom memory allocation routines.
+ *
+ * Return       None
+ *
+ * Description
+ *      This routine just uses malloc to allocate the memory and
+ *      increments the amount of memory allocated.  It is passed
+ *      into setVlenMemManager.
+ *
+ *  Note: exact copy from the C version.
+ *  (Not used now)
+ *-------------------------------------------------------------------------
+ */
 #if 0 // not used now
 static void *test_vlstr_alloc_custom(size_t size, void *info)
 {
@@ -74,16 +76,22 @@ static void *test_vlstr_alloc_custom(size_t size, void *info)
 }
 #endif
 
-/****************************************************************
-**
-**  test_vlstr_free_custom(): Test VL datatype custom memory
-**      allocation routines.  This routine just uses free to
-**      release the memory and decrements the amount of memory
-**      allocated.  It is passed into setVlenMemManager.
-**
-**  Note: exact copy from the C version.
-**  (Not used now)
-****************************************************************/
+/*-------------------------------------------------------------------------
+ * Function:    test_vlstr_free_custom
+ *
+ * Purpose      Test VL datatype custom memory de-allocation routines.
+ *
+ * Return       None
+ *
+ * Description
+ *      This routine just uses free to release the memory and
+ *      decrements the amount of memory allocated.  It is passed
+ *      into setVlenMemManager.
+ *
+ *  Note: exact copy from the C version.
+ *  (Not used now)
+ *-------------------------------------------------------------------------
+ */
 #if 0 // not used now
 static void test_vlstr_free_custom(void *_mem, void *info)
 {
@@ -109,11 +117,11 @@ static void test_vlstr_free_custom(void *_mem, void *info)
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_dataset
  *
- * Purpose:     Test writing/reading VL strings on datasets.
+ * Purpose      Test writing/reading VL strings on datasets.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -125,10 +133,11 @@ static void test_vlstr_free_custom(void *_mem, void *info)
 const H5std_string DSET1_NAME("String_ds");
 const H5std_string DSET1_DATA("String Dataset");
 
-static void test_vlstring_dataset()
+static void
+test_vlstring_dataset()
 {
     char *dynstring_ds_write = NULL;
-    char *string_ds_check = NULL;
+    char *string_ds_check    = NULL;
 
     // Output message about test being performed
     SUBTEST("VL String on Datasets");
@@ -144,7 +153,7 @@ static void test_vlstring_dataset()
         Group root = file1.openGroup("/");
 
         // Create dataspace for the dataset.
-        DataSpace ds_space (H5S_SCALAR);
+        DataSpace ds_space(H5S_SCALAR);
 
         // Create an dataset in the root group.
         DataSet dset1 = root.createDataSet(DSET1_NAME, vlst, ds_space);
@@ -154,17 +163,19 @@ static void test_vlstring_dataset()
 
         // Read and verify the dataset string as a string of chars.
         dset1.read(&string_ds_check, vlst);
-        if(HDstrcmp(string_ds_check, DSET1_DATA.c_str())!=0)
-            TestErrPrintf("Line %d: Attribute data different: DSET1_DATA=%s,string_ds_check=%s\n",__LINE__, DSET1_DATA.c_str(), string_ds_check);
+        if (HDstrcmp(string_ds_check, DSET1_DATA.c_str()) != 0)
+            TestErrPrintf("Line %d: Attribute data different: DSET1_DATA=%s,string_ds_check=%s\n", __LINE__,
+                          DSET1_DATA.c_str(), string_ds_check);
 
-        HDfree(string_ds_check);  // note: no need for std::string test
+        HDfree(string_ds_check); // note: no need for std::string test
         string_ds_check = NULL;
 
         // Read and verify the dataset string as an std::string.
         H5std_string read_str;
         dset1.read(read_str, vlst);
         if (read_str != DSET1_DATA)
-            TestErrPrintf("Line %d: Attribute data different: DSET1_DATA=%s,read_str=%s\n",__LINE__, DSET1_DATA.c_str(), read_str.c_str());
+            TestErrPrintf("Line %d: Attribute data different: DSET1_DATA=%s,read_str=%s\n", __LINE__,
+                          DSET1_DATA.c_str(), read_str.c_str());
 
         // Close the dataset.
         dset1.close();
@@ -172,7 +183,7 @@ static void test_vlstring_dataset()
         // Test scalar type dataset with 1 value.
         dset1 = root.createDataSet("test_scalar_small", vlst, ds_space);
 
-        dynstring_ds_write = (char*)HDcalloc(1, sizeof(char));
+        dynstring_ds_write = static_cast<char *>(HDcalloc(2, sizeof(char)));
         HDmemset(dynstring_ds_write, 'A', 1);
 
         // Write data to the dataset, then read it back.
@@ -180,8 +191,9 @@ static void test_vlstring_dataset()
         dset1.read(&string_ds_check, vlst);
 
         // Verify data read.
-        if(HDstrcmp(string_ds_check,dynstring_ds_write)!=0)
-            TestErrPrintf("VL string datasets don't match!, dynstring_ds_write=%s, string_ds_check=%s\n",dynstring_ds_write,string_ds_check);
+        if (HDstrcmp(string_ds_check, dynstring_ds_write) != 0)
+            TestErrPrintf("VL string datasets don't match!, dynstring_ds_write=%s, string_ds_check=%s\n",
+                          dynstring_ds_write, string_ds_check);
         HDfree(string_ds_check);
         string_ds_check = NULL;
         dset1.close();
@@ -197,46 +209,46 @@ static void test_vlstring_dataset()
     } // end try block
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vlstring_dataset()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if(dynstring_ds_write)
+    if (dynstring_ds_write)
         HDfree(dynstring_ds_write);
-    if(string_ds_check)
+    if (string_ds_check)
         HDfree(string_ds_check);
-}   // test_vlstring_dataset()
+} // test_vlstring_dataset()
 
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_array_dataset
  *
- * Purpose:     Test writing/reading VL string array to/from datasets.
+ * Purpose      Test writing/reading VL string array to/from datasets.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              July, 2009
  *
  *-------------------------------------------------------------------------
  */
 const H5std_string DSSTRARR_NAME("StringArray_dset");
-static void test_vlstring_array_dataset()
+
+static void
+test_vlstring_array_dataset()
 {
-    const char *string_ds_array[SPACE1_DIM1]= {
-        "Line 1", "Line 2", "Line 3", "Line 4"
-        };   // Information to write
+    const char *string_ds_array[SPACE1_DIM1] = {"Line 1", "Line 2", "Line 3",
+                                                "Line 4"}; // Information to write
 
     // Output message about test being performed
     SUBTEST("VL String Array on Datasets");
 
-    H5File* file1 = NULL;
+    H5File *file1 = NULL;
     try {
         // Create file.
         file1 = new H5File(FILENAME, H5F_ACC_RDWR);
 
         // Create dataspace for datasets.
-        hsize_t dims1[] = {SPACE1_DIM1};
+        hsize_t   dims1[] = {SPACE1_DIM1};
         DataSpace ds_space(SPACE1_RANK, dims1);
 
         // Create a datatype to refer to.
@@ -252,10 +264,10 @@ static void test_vlstring_array_dataset()
         dataset.read(string_ds_check, vlst);
 
         hsize_t ii;
-        for (ii = 0; ii < SPACE1_DIM1; ii++)
-        {
-            if(HDstrcmp(string_ds_check[ii], string_ds_array[ii])!=0)
-                TestErrPrintf("Line %d: Dataset data different: written=%s,read=%s\n",__LINE__, string_ds_array[ii], string_ds_check[ii]);
+        for (ii = 0; ii < SPACE1_DIM1; ii++) {
+            if (HDstrcmp(string_ds_check[ii], string_ds_array[ii]) != 0)
+                TestErrPrintf("Line %d: Dataset data different: written=%s,read=%s\n", __LINE__,
+                              string_ds_array[ii], string_ds_check[ii]);
 
             HDfree(string_ds_check[ii]);
         }
@@ -273,14 +285,14 @@ static void test_vlstring_array_dataset()
 
         // Create and write another dataset.
         DataSet dataset2(file1->createDataSet("Dataset2", vlst, scalar_space));
-        char *wdata2 = (char*)HDcalloc(65534, sizeof(char));
+        char *  wdata2 = static_cast<char *>(HDcalloc(65534, sizeof(char)));
         HDmemset(wdata2, 'A', 65533);
         dataset2.write(&wdata2, vlst);
 
         char *rdata2;
         dataset2.read(&rdata2, vlst);
-        if (HDstrcmp(wdata2, rdata2)!=0)
-            TestErrPrintf("Line %d: Dataset data different: written=%s,read=%s\n",__LINE__, wdata2, rdata2);
+        if (HDstrcmp(wdata2, rdata2) != 0)
+            TestErrPrintf("Line %d: Dataset data different: written=%s,read=%s\n", __LINE__, wdata2, rdata2);
 
         // Release resources from second dataset operation.
         scalar_space.close();
@@ -297,33 +309,32 @@ static void test_vlstring_array_dataset()
     } // end try
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vlstring_array_dataset()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if(file1)
-        delete file1;
+    delete file1;
 } // end test_vlstring_array_dataset()
 
 /*-------------------------------------------------------------------------
  * Function:    test_vlstrings_special
  *
- * Purpose:     Test VL string code for special string cases, nil and
+ * Purpose      Test VL string code for special string cases, nil and
  *              zero-sized.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
-static void test_vlstrings_special()
+static void
+test_vlstrings_special()
 {
-    const char *wdata[SPACE1_DIM1] = {"one", "two", "", "four"};
+    const char *wdata[SPACE1_DIM1]  = {"one", "two", "", "four"};
     const char *wdata2[SPACE1_DIM1] = {NULL, NULL, NULL, NULL};
-    char *rdata[SPACE1_DIM1];   // Information read in
+    char *      rdata[SPACE1_DIM1]; // Information read in
 
     // Output message about test being performed.
     SUBTEST("Special VL Strings");
@@ -333,7 +344,7 @@ static void test_vlstrings_special()
         H5File file1(FILENAME, H5F_ACC_TRUNC);
 
         // Create dataspace for datasets.
-        hsize_t dims1[] = {SPACE1_DIM1};
+        hsize_t   dims1[] = {SPACE1_DIM1};
         DataSpace sid1(SPACE1_RANK, dims1);
 
         // Create a datatype to refer to.
@@ -347,33 +358,33 @@ static void test_vlstrings_special()
 
         // Check data read in.
         hsize_t ii; // counting variable
-        for (ii=0; ii<SPACE1_DIM1; ii++)
-            if(rdata[ii]!=NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n",(int)ii,rdata[ii]);
+        for (ii = 0; ii < SPACE1_DIM1; ii++)
+            if (rdata[ii] != NULL)
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", static_cast<int>(ii), rdata[ii]);
 
         // Write dataset to disk, then read it back.
         dataset.write(wdata, vlst);
         dataset.read(rdata, vlst);
 
         // Compare data read in.
-        for (ii = 0; ii < SPACE1_DIM1; ii++)
-        {
+        for (ii = 0; ii < SPACE1_DIM1; ii++) {
             size_t wlen = HDstrlen(wdata[ii]);
             size_t rlen = HDstrlen(rdata[ii]);
-            if(wlen != rlen)
-            {
-                TestErrPrintf("VL data lengths don't match!, strlen(wdata[%d])=%u, strlen(rdata[%d])=%u\n", (int)ii, (unsigned)wlen, (int)ii, (unsigned)rlen);
+            if (wlen != rlen) {
+                TestErrPrintf("VL data lengths don't match!, strlen(wdata[%d])=%u, strlen(rdata[%d])=%u\n",
+                              static_cast<int>(ii), static_cast<unsigned>(wlen), static_cast<int>(ii),
+                              static_cast<unsigned>(rlen));
                 continue;
-            } // end if
-            if(HDstrcmp(wdata[ii],rdata[ii]) != 0)
-            {
-                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n", (int)ii, wdata[ii], (int)ii, rdata[ii]);
+            }
+            if (HDstrcmp(wdata[ii], rdata[ii]) != 0) {
+                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",
+                              static_cast<int>(ii), wdata[ii], static_cast<int>(ii), rdata[ii]);
                 continue;
-            } // end if
-        } // end for
+            }
+        }
 
         // Reclaim the read VL data.
-        DataSet::vlenReclaim((void *)rdata, vlst, sid1);
+        DataSet::vlenReclaim(static_cast<void *>(rdata), vlst, sid1);
 
         // Close Dataset.
         dataset.close();
@@ -385,7 +396,7 @@ static void test_vlstrings_special()
         // Create the property list and set the fill value for the second
         // dataset.
         DSetCreatPropList dcpl;
-        char *fill = NULL;  // Fill value
+        char *            fill = NULL; // Fill value
         dcpl.setFillValue(vlst, &fill);
         dataset = file1.createDataSet("Dataset4", vlst, sid1, dcpl);
 
@@ -396,9 +407,9 @@ static void test_vlstrings_special()
         dataset.read(rdata, vlst);
 
         // Check data read in.
-        for (ii=0; ii<SPACE1_DIM1; ii++)
-            if(rdata[ii]!=NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n",(int)ii,rdata[ii]);
+        for (ii = 0; ii < SPACE1_DIM1; ii++)
+            if (rdata[ii] != NULL)
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", static_cast<int>(ii), rdata[ii]);
 
         // Try to write nil strings to disk.
         dataset.write(wdata2, vlst);
@@ -407,9 +418,9 @@ static void test_vlstrings_special()
         dataset.read(rdata, vlst);
 
         // Check data read in.
-        for (ii=0; ii<SPACE1_DIM1; ii++)
-            if(rdata[ii]!=NULL)
-                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n",(int)ii,rdata[ii]);
+        for (ii = 0; ii < SPACE1_DIM1; ii++)
+            if (rdata[ii] != NULL)
+                TestErrPrintf("VL doesn't match!, rdata[%d]=%p\n", static_cast<int>(ii), rdata[ii]);
 
         // Close objects and file.
         dataset.close();
@@ -421,8 +432,7 @@ static void test_vlstrings_special()
     } // end try
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vlstrings_special()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 } // test_vlstrings_special
@@ -430,22 +440,24 @@ static void test_vlstrings_special()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_type
  *
- * Purpose:     Test if VL string is treated as string.
+ * Purpose      Test if VL string is treated as string.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
-const H5std_string      VLSTR_TYPE("vl_string_type");
-static void test_vlstring_type()
+const H5std_string VLSTR_TYPE("vl_string_type");
+
+static void
+test_vlstring_type()
 {
     // Output message about test being performed.
     SUBTEST("VL String Type");
 
-    H5File* file1 = NULL;
+    H5File *file1 = NULL;
     try {
         // Open file.
         file1 = new H5File(FILENAME, H5F_ACC_RDWR);
@@ -456,22 +468,26 @@ static void test_vlstring_type()
         // Change padding and verify it.
         vlst.setStrpad(H5T_STR_NULLPAD);
         H5T_str_t pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Convert to variable-length string.
         vlst.setSize(H5T_VARIABLE);
 
         // Check if datatype is VL string.
         H5T_class_t type_class = vlst.getClass();
-        verify_val(type_class, H5T_STRING, "DataType::getClass", __LINE__, __FILE__);
+        verify_val(static_cast<long>(type_class), static_cast<long>(H5T_STRING), "DataType::getClass",
+                   __LINE__, __FILE__);
         bool is_variable_str = vlst.isVariableStr();
         verify_val(is_variable_str, true, "DataType::isVariableStr", __LINE__, __FILE__);
 
         // Check default character set and padding.
         H5T_cset_t cset = vlst.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
+        verify_val(static_cast<long>(cset), static_cast<long>(H5T_CSET_ASCII), "StrType::getCset", __LINE__,
+                   __FILE__);
         pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
         // Commit variable-length string datatype to storage.
         vlst.commit(*file1, VLSTR_TYPE);
@@ -494,30 +510,18 @@ static void test_vlstring_type()
         // Open file.
         file1 = new H5File(FILENAME, H5F_ACC_RDWR);
 
-        { // deprecated
-        // Open the variable-length string datatype just created.
-        vlst = file1->openStrType(VLSTR_TYPE);
-
-        // Verify character set and padding.
-        cset = vlst.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
-        pad = vlst.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
-
-        // Close type to test new function.
-        vlst.close();
-        } // deprecated
-
-        // Open the variable-length string datatype just created.
+        // Open the variable-length string datatype just created
         StrType vlst2(*file1, VLSTR_TYPE);
 
-        // Verify character set and padding.
+        // Verify character set and padding
         cset = vlst2.getCset();
-        verify_val(cset, H5T_CSET_ASCII, "StrType::getCset", __LINE__, __FILE__);
+        verify_val(static_cast<long>(cset), static_cast<long>(H5T_CSET_ASCII), "StrType::getCset", __LINE__,
+                   __FILE__);
         pad = vlst2.getStrpad();
-        verify_val(pad, H5T_STR_NULLPAD, "StrType::getStrpad", __LINE__, __FILE__);
+        verify_val(static_cast<long>(pad), static_cast<long>(H5T_STR_NULLPAD), "StrType::getStrpad", __LINE__,
+                   __FILE__);
 
-        // Close datatype and file.
+        // Close datatype and file
         vlst2.close();
         file1->close();
 
@@ -525,28 +529,27 @@ static void test_vlstring_type()
     } // end try block
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vlstring_type()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
-    if(file1)
-        delete file1;
+    delete file1;
 } // end test_vlstring_type()
 
 /*-------------------------------------------------------------------------
  * Function:    test_compact_vlstring
  *
- * Purpose:     Test storing VL strings in compact datasets.
+ * Purpose      Test storing VL strings in compact datasets.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
-static void test_compact_vlstring()
+static void
+test_compact_vlstring()
 {
     // Output message about test being performed
     SUBTEST("VL Strings on Compact Dataset");
@@ -556,7 +559,7 @@ static void test_compact_vlstring()
         H5File file1(FILENAME, H5F_ACC_TRUNC);
 
         // Create dataspace for datasets
-        hsize_t dims1[] = {SPACE1_DIM1};
+        hsize_t   dims1[] = {SPACE1_DIM1};
         DataSpace sid1(SPACE1_RANK, dims1);
 
         // Create a datatype to refer to
@@ -574,24 +577,27 @@ static void test_compact_vlstring()
         dataset.write(wdata, vlst);
 
         // Read dataset from disk
-        char *rdata[SPACE1_DIM1];   // Information read in
+        char *rdata[SPACE1_DIM1]; // Information read in
         dataset.read(rdata, vlst);
 
         // Compare data read in
         hsize_t i;
-        for (i=0; i<SPACE1_DIM1; i++) {
-            if (HDstrlen(wdata[i])!=strlen(rdata[i])) {
-                TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",(int)i,(int)strlen(wdata[i]),(int)i,(int)strlen(rdata[i]));
+        for (i = 0; i < SPACE1_DIM1; i++) {
+            if (HDstrlen(wdata[i]) != strlen(rdata[i])) {
+                TestErrPrintf("VL data length don't match!, strlen(wdata[%d])=%d, strlen(rdata[%d])=%d\n",
+                              static_cast<int>(i), static_cast<int>(HDstrlen(wdata[i])), static_cast<int>(i),
+                              static_cast<int>(HDstrlen(rdata[i])));
                 continue;
             } // end if
-            if (HDstrcmp(wdata[i],rdata[i]) != 0) {
-                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",(int)i,wdata[i],(int)i,rdata[i]);
+            if (HDstrcmp(wdata[i], rdata[i]) != 0) {
+                TestErrPrintf("VL data values don't match!, wdata[%d]=%s, rdata[%d]=%s\n",
+                              static_cast<int>(i), wdata[i], static_cast<int>(i), rdata[i]);
                 continue;
             } // end if
-        } // end for
+        }     // end for
 
         // Reclaim the read VL data
-        DataSet::vlenReclaim((void *)rdata, vlst, sid1);
+        DataSet::vlenReclaim(static_cast<void *>(rdata), vlst, sid1);
 
         // Close objects and file
         dataset.close();
@@ -604,32 +610,29 @@ static void test_compact_vlstring()
     } // end try
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_compact_vlstrings()", __LINE__, __FILE__, E.getCDetailMsg());
     }
-}   // test_compact_vlstrings
+} // test_compact_vlstrings
 
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_attribute
  *
- * Purpose:     Test writing/reading VL strings on attributes.
+ * Purpose      Test writing/reading VL strings on attributes.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
-// String for writing to attribute
-static char *string_att_write=NULL;
-
-// Info for a string attribute
+static char *      string_att_write = NULL;
 const H5std_string ATTRSTR_NAME("String_attr");
 const H5std_string ATTRSTR_DATA("String Attribute");
 
-static void test_vlstring_attribute()
+static void
+test_vlstring_attribute()
 {
     // Output message about test being performed
     SUBTEST("VL String on Attributes");
@@ -645,7 +648,7 @@ static void test_vlstring_attribute()
         Group root = file1.openGroup("/");
 
         // Create dataspace for the attribute.
-        DataSpace att_space (H5S_SCALAR);
+        DataSpace att_space(H5S_SCALAR);
 
         // Create an attribute for the root group.
         Attribute gr_attr = root.createAttribute(ATTRSTR_NAME, vlst, att_space);
@@ -656,16 +659,18 @@ static void test_vlstring_attribute()
         // Read and verify the attribute string as a string of chars.
         char *string_att_check;
         gr_attr.read(vlst, &string_att_check);
-        if(HDstrcmp(string_att_check, ATTRSTR_DATA.c_str())!=0)
-            TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,string_att_check=%s\n",__LINE__, ATTRSTR_DATA.c_str(), string_att_check);
+        if (HDstrcmp(string_att_check, ATTRSTR_DATA.c_str()) != 0)
+            TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,string_att_check=%s\n",
+                          __LINE__, ATTRSTR_DATA.c_str(), string_att_check);
 
-        HDfree(string_att_check);  // note: no need for std::string test
+        HDfree(string_att_check); // note: no need for std::string test
 
         // Read and verify the attribute string as an std::string.
         H5std_string read_str;
         gr_attr.read(vlst, read_str);
         if (read_str != ATTRSTR_DATA)
-            TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,read_str=%s\n",__LINE__, ATTRSTR_DATA.c_str(), read_str.c_str());
+            TestErrPrintf("Line %d: Attribute data different: ATTRSTR_DATA=%s,read_str=%s\n", __LINE__,
+                          ATTRSTR_DATA.c_str(), read_str.c_str());
 
         // Close group's attribute.
         gr_attr.close();
@@ -673,7 +678,7 @@ static void test_vlstring_attribute()
         // Test creating a "large" sized string attribute
         gr_attr = root.createAttribute("test_scalar_large", vlst, att_space);
 
-        string_att_write = (char*)HDcalloc(8192, sizeof(char));
+        string_att_write = static_cast<char *>(HDcalloc(8192, sizeof(char)));
         HDmemset(string_att_write, 'A', 8191);
 
         // Write data to the attribute, then read it back.
@@ -681,8 +686,9 @@ static void test_vlstring_attribute()
         gr_attr.read(vlst, &string_att_check);
 
         // Verify data read.
-        if(HDstrcmp(string_att_check,string_att_write)!=0)
-            TestErrPrintf("VL string attributes don't match!, string_att_write=%s, string_att_check=%s\n",string_att_write,string_att_check);
+        if (HDstrcmp(string_att_check, string_att_write) != 0)
+            TestErrPrintf("VL string attributes don't match!, string_att_write=%s, string_att_check=%s\n",
+                          string_att_write, string_att_check);
 
         // Release resources.
         HDfree(string_att_check);
@@ -694,21 +700,20 @@ static void test_vlstring_attribute()
     } // end try block
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vlstring_attribute()", __LINE__, __FILE__, E.getCDetailMsg());
     }
-}   // test_vlstring_attribute()
+} // test_vlstring_attribute()
 
 #if 0
 /*-------------------------------------------------------------------------
  * Function:    test_read_vl_string_attribute
  *
- * Purpose:     Test reading VL strings from attributes.
+ * Purpose      Test reading VL strings from attributes.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
@@ -766,22 +771,22 @@ static void test_read_vl_string_attribute()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstring_array_attribute
  *
- * Purpose:     Test writing/reading VL string array to/from attributes.
+ * Purpose      Test writing/reading VL string array to/from attributes.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              July, 2009
  *
  *-------------------------------------------------------------------------
  */
 const H5std_string ATTRSTRARR_NAME("StringArray_attr");
 
-static void test_vlstring_array_attribute()
+static void
+test_vlstring_array_attribute()
 {
-    const char *string_att_array[SPACE1_DIM1]= {
-        "Line 1", "Line 2", "Line 3", "Line 4"
-        };   // Information to write
+    const char *string_att_array[SPACE1_DIM1] = {"Line 1", "Line 2", "Line 3",
+                                                 "Line 4"}; // Information to write
 
     // Output message about test being performed
     SUBTEST("VL String Array on Attributes");
@@ -797,7 +802,7 @@ static void test_vlstring_array_attribute()
         Group root = file1.openGroup("/");
 
         // Create dataspace for datasets.
-        hsize_t dims1[] = {SPACE1_DIM1};
+        hsize_t   dims1[] = {SPACE1_DIM1};
         DataSpace att_space(SPACE1_RANK, dims1);
 
         // Create an attribute for the root group.
@@ -812,12 +817,12 @@ static void test_vlstring_array_attribute()
         gr_attr.read(vlst, &string_att_check);
 
         hsize_t ii;
-        for (ii = 0; ii < SPACE1_DIM1; ii++)
-        {
-            if(HDstrcmp(string_att_check[ii], string_att_array[ii])!=0)
-                TestErrPrintf("Line %d: Attribute data different: written=%s,read=%s\n",__LINE__, string_att_check[ii], string_att_check[ii]);
+        for (ii = 0; ii < SPACE1_DIM1; ii++) {
+            if (HDstrcmp(string_att_check[ii], string_att_array[ii]) != 0)
+                TestErrPrintf("Line %d: Attribute data different: written=%s,read=%s\n", __LINE__,
+                              string_att_check[ii], string_att_check[ii]);
 
-            HDfree(string_att_check[ii]);  // note: no need for std::string test
+            HDfree(string_att_check[ii]); // note: no need for std::string test
         }
 
         // Close group's attribute.
@@ -828,15 +833,14 @@ static void test_vlstring_array_attribute()
     } // end try block
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vlstring_array_attribute()", __LINE__, __FILE__, E.getCDetailMsg());
     }
-}   // test_vlstring_array_attribute()
+} // test_vlstring_array_attribute()
 
 /* Helper routine for test_vl_rewrite() */
-static void write_scalar_dset(H5File& file, DataType& type, DataSpace& space,
-                              char *name, char *data)
+static void
+write_scalar_dset(H5File &file, DataType &type, DataSpace &space, char *name, char *data)
 {
     DataSet dset;
     try {
@@ -844,34 +848,34 @@ static void write_scalar_dset(H5File& file, DataType& type, DataSpace& space,
         dset.write(&data, type, space, space);
         dset.close();
     } // end try
-    catch (FileIException& ferr) {
+    catch (FileIException &ferr) {
         throw;
     }
-    catch (DataSetIException& derr) {
+    catch (DataSetIException &derr) {
         throw;
     }
 }
 
 /* Helper routine for test_vl_rewrite() */
-static void read_scalar_dset(H5File& file, DataType& type, DataSpace& space,
-                             char *name, char *data)
+static void
+read_scalar_dset(H5File &file, DataType &type, DataSpace &space, char *name, char *data)
 {
-    char *data_read;
+    char *  data_read;
     DataSet dset;
     try {
         dset = file.openDataSet(name);
         dset.read(&data_read, type, space, space);
         dset.close();
 
-        if(HDstrcmp(data, data_read))
+        if (HDstrcmp(data, data_read) != 0)
             TestErrPrintf("Expected %s for dataset %s but read %s\n", data, name, data_read);
 
         HDfree(data_read);
     } // end try
-    catch (FileIException& ferr) {
+    catch (FileIException &ferr) {
         throw;
     }
-    catch (DataSetIException& derr) {
+    catch (DataSetIException &derr) {
         throw;
     }
 }
@@ -879,19 +883,21 @@ static void read_scalar_dset(H5File& file, DataType& type, DataSpace& space,
 /*-------------------------------------------------------------------------
  * Function:    test_vl_rewrite
  *
- * Purpose:     Test I/O on VL strings when many objects in the file
+ * Purpose      Test I/O on VL strings when many objects in the file
  *              have been linked/unlinked.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler (use C version)
+ * Programmer   Binh-Minh Ribler (use C version)
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
 const H5std_string FILENAME2("tvlstr2.h5");
-const int REWRITE_NDATASETS = 32;
-static void test_vl_rewrite()
+const int          REWRITE_NDATASETS = 32;
+
+static void
+test_vl_rewrite()
 {
     // Output message about test being performed
     SUBTEST("I/O on VL strings with link/unlink");
@@ -905,38 +911,38 @@ static void test_vl_rewrite()
         StrType type(0, H5T_VARIABLE);
 
         // Create dataspace for the attribute.
-        DataSpace space (H5S_SCALAR);
+        DataSpace space(H5S_SCALAR);
 
         // Create in file 1.
-        int i;
+        int  i;
         char name[256]; // Buffer for names & data
-        for (i=0; i<REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+        for (i = 0; i < REWRITE_NDATASETS; i++) {
+            snprintf(name, sizeof(name), "/set_%d", i);
             write_scalar_dset(file1, type, space, name, name);
         }
 
         // Effectively copy data from file 1 to 2.
-        for (i=0; i<REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+        for (i = 0; i < REWRITE_NDATASETS; i++) {
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file1, type, space, name, name);
             write_scalar_dset(file2, type, space, name, name);
         }
 
         // Read back from file 2.
-        for (i=0; i<REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+        for (i = 0; i < REWRITE_NDATASETS; i++) {
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file2, type, space, name, name);
         }
 
         // Remove from file 2.
-        for (i=0; i<REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+        for (i = 0; i < REWRITE_NDATASETS; i++) {
+            snprintf(name, sizeof(name), "/set_%d", i);
             file2.unlink(name);
         }
 
         // Effectively copy from file 1 to file 2.
-        for (i=0; i<REWRITE_NDATASETS; i++) {
-            sprintf(name, "/set_%d", i);
+        for (i = 0; i < REWRITE_NDATASETS; i++) {
+            snprintf(name, sizeof(name), "/set_%d", i);
             read_scalar_dset(file1, type, space, name, name);
             write_scalar_dset(file2, type, space, name, name);
         }
@@ -951,8 +957,7 @@ static void test_vl_rewrite()
     } // end try
 
     // Catch all exceptions.
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("test_vl_rewrite()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 } // end test_vl_rewrite()
@@ -960,17 +965,17 @@ static void test_vl_rewrite()
 /*-------------------------------------------------------------------------
  * Function:    test_vlstrings
  *
- * Purpose:     VL string testing main routine.
+ * Purpose      VL string testing main routine.
  *
- * Return:      None
+ * Return       None
  *
- * Programmer:  Binh-Minh Ribler
+ * Programmer   Binh-Minh Ribler
  *              January, 2007
  *
  *-------------------------------------------------------------------------
  */
-extern "C"
-void test_vlstrings()
+extern "C" void
+test_vlstrings()
 {
     // Output message about test being performed
     MESSAGE(5, ("Testing Variable-Length Strings"));
@@ -992,25 +997,19 @@ void test_vlstrings()
     // Test writing VL datasets in files with lots of unlinking
     test_vl_rewrite();
 
-}   // test_vlstrings()
+} // test_vlstrings()
 
-
 /*-------------------------------------------------------------------------
  * Function:    cleanup_vlstrings
  *
- * Purpose:     Cleanup temporary test files
- *
- * Return:      none
- *
- * Programmer:  Quincey Koziol
- *              September 10, 1999
+ * Purpose      Cleanup temporary test files
  *
+ * Return       none
  *-------------------------------------------------------------------------
  */
-extern "C"
-void cleanup_vlstrings()
+extern "C" void
+cleanup_vlstrings()
 {
     HDremove(FILENAME.c_str());
     HDremove(FILENAME2.c_str());
 }
-
