@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -25,6 +24,7 @@ import hdf.hdf5lib.HDF5Constants;
 import hdf.hdf5lib.exceptions.HDF5Exception;
 import hdf.hdf5lib.exceptions.HDF5FunctionArgumentException;
 import hdf.hdf5lib.exceptions.HDF5LibraryException;
+import hdf.hdf5lib.structs.H5F_info2_t;
 
 import org.junit.After;
 import org.junit.Before;
@@ -36,24 +36,24 @@ import org.junit.rules.TestName;
 public class TestH5P {
     @Rule public TestName testname = new TestName();
 
-    private static final String H5_FILE = "test.h5";
+    private static final String H5_FILE = "testP.h5";
     private static final int DIM_X = 4;
     private static final int DIM_Y = 6;
     long[] H5dims = { DIM_X, DIM_Y };
-    long H5fid = -1;
-    long H5dsid = -1;
-    long H5did = -1;
-    long lapl_id = -1;
-    long fapl_id = -1;
-    long fcpl_id = -1;
-    long ocpl_id = -1;
-    long ocp_plist_id = -1;
-    long lcpl_id = -1;
-    long plapl_id = -1;
-    long plist_id = -1;
-    long gapl_id = -1;
-    long gcpl_id = -1;
-    long acpl_id = -1;
+    long H5fid = HDF5Constants.H5I_INVALID_HID;
+    long H5dsid = HDF5Constants.H5I_INVALID_HID;
+    long H5did = HDF5Constants.H5I_INVALID_HID;
+    long lapl_id = HDF5Constants.H5I_INVALID_HID;
+    long fapl_id = HDF5Constants.H5I_INVALID_HID;
+    long fcpl_id = HDF5Constants.H5I_INVALID_HID;
+    long ocpl_id = HDF5Constants.H5I_INVALID_HID;
+    long ocp_plist_id = HDF5Constants.H5I_INVALID_HID;
+    long lcpl_id = HDF5Constants.H5I_INVALID_HID;
+    long plapl_id = HDF5Constants.H5I_INVALID_HID;
+    long plist_id = HDF5Constants.H5I_INVALID_HID;
+    long gapl_id = HDF5Constants.H5I_INVALID_HID;
+    long gcpl_id = HDF5Constants.H5I_INVALID_HID;
+    long acpl_id = HDF5Constants.H5I_INVALID_HID;
 
     private final void _deleteFile(String filename) {
         File file = new File(filename);
@@ -64,7 +64,7 @@ public class TestH5P {
     }
 
     private final long _createDataset(long fid, long dsid, String name, long dapl) {
-        long did = -1;
+        long did = HDF5Constants.H5I_INVALID_HID;
         try {
             did = H5.H5Dcreate(fid, name, HDF5Constants.H5T_STD_I32BE, dsid,
                     HDF5Constants.H5P_DEFAULT, HDF5Constants.H5P_DEFAULT, dapl);
@@ -208,12 +208,12 @@ public class TestH5P {
 
     @Test(expected = HDF5FunctionArgumentException.class)
     public void testH5Pset_libver_bounds_invalidlow() throws Throwable {
-        H5.H5Pset_libver_bounds(fapl_id, 5, HDF5Constants.H5F_LIBVER_LATEST);
+        H5.H5Pset_libver_bounds(fapl_id, HDF5Constants.H5F_LIBVER_LATEST+1, HDF5Constants.H5F_LIBVER_LATEST);
     }
 
     @Test(expected = HDF5FunctionArgumentException.class)
     public void testH5Pset_libver_bounds_invalidhigh() throws Throwable {
-        H5.H5Pset_libver_bounds(fapl_id, HDF5Constants.H5F_LIBVER_V110, HDF5Constants.H5F_LIBVER_V110+1);
+        H5.H5Pset_libver_bounds(fapl_id, HDF5Constants.H5F_LIBVER_LATEST, HDF5Constants.H5F_LIBVER_LATEST+1);
     }
 
     @Test
@@ -886,30 +886,6 @@ public class TestH5P {
         H5.H5Pget_elink_prefix(plapl_id, null);
     }
 
-    @Test(expected = NullPointerException.class)
-    public void testH5Pget_version_null() throws Throwable {
-        H5.H5Pget_version(fcpl_id, null);
-    }
-
-    @Test
-    public void testH5Pget_version() {
-        int[] version_info = {255,255,255,255};
-
-        try {
-            _createH5File(fcpl_id, fapl_id);
-            H5.H5Pget_version(fcpl_id, version_info);
-            deleteH5file();
-        }
-        catch (Throwable err) {
-            err.printStackTrace();
-            fail("H5Pget_version: " + err);
-        }
-        assertTrue("super block version: "+version_info[0], version_info[0] == 0);
-        assertTrue("global freelist version: "+version_info[1], version_info[1] == 0);
-        assertTrue("symbol table version: "+version_info[2], version_info[2] == 0);
-        assertTrue("shared object header version: "+version_info[3], version_info[3] == 0);
-    }
-
     @Test(expected = NullPointerException.class)
     public void testH5Pget_userblock_null() throws Throwable {
         H5.H5Pget_userblock(fcpl_id, null);
@@ -917,7 +893,6 @@ public class TestH5P {
 
     @Test
     public void testH5P_userblock() {
-        int[] version_info = {255,255,255,255};
         long[] size = {0};
 
         try {
@@ -931,7 +906,10 @@ public class TestH5P {
             fcpl_id =  H5.H5Fget_create_plist(H5fid);
 
             /* Get the file's version information */
-            H5.H5Pget_version(fcpl_id, version_info);
+            H5F_info2_t finfo = H5.H5Fget_info(H5fid);
+            assertTrue("super block version: "+finfo.super_version, finfo.super_version == 0);
+            assertTrue("free-space manager version: "+finfo.free_version, finfo.free_version == 0);
+            assertTrue("shared object header version: "+finfo.sohm_version, finfo.sohm_version == 0);
             H5.H5Pget_userblock(fcpl_id, size);
             deleteH5file();
         }
@@ -939,10 +917,6 @@ public class TestH5P {
             err.printStackTrace();
             fail("H5Pget_userblock: " + err);
         }
-        assertTrue("super block version: "+version_info[0], version_info[0] == 0);
-        assertTrue("global freelist version: "+version_info[1], version_info[1] == 0);
-        assertTrue("symbol table version: "+version_info[2], version_info[2] == 0);
-        assertTrue("shared object header version: "+version_info[3], version_info[3] == 0);
         assertTrue("user block size: "+size[0], size[0] == 1024);
     }
 
@@ -953,7 +927,6 @@ public class TestH5P {
 
     @Test
     public void testH5P_sizes() {
-        int[] version_info = {255,255,255,255};
         long[] size = {0,0};
 
         try {
@@ -967,7 +940,10 @@ public class TestH5P {
             fcpl_id =  H5.H5Fget_create_plist(H5fid);
 
             /* Get the file's version information */
-            H5.H5Pget_version(fcpl_id, version_info);
+            H5F_info2_t finfo = H5.H5Fget_info(H5fid);
+            assertTrue("super block version: "+finfo.super_version, finfo.super_version == 0);
+            assertTrue("free-space manager version: "+finfo.free_version, finfo.free_version == 0);
+            assertTrue("shared object header version: "+finfo.sohm_version, finfo.sohm_version == 0);
             H5.H5Pget_sizes(fcpl_id, size);
             deleteH5file();
         }
@@ -975,10 +951,6 @@ public class TestH5P {
             err.printStackTrace();
             fail("H5Pget_sizes: " + err);
         }
-        assertTrue("super block version: "+version_info[0], version_info[0] == 0);
-        assertTrue("global freelist version: "+version_info[1], version_info[1] == 0);
-        assertTrue("symbol table version: "+version_info[2], version_info[2] == 0);
-        assertTrue("shared object header version: "+version_info[3], version_info[3] == 0);
         assertTrue("sizeof_addr size: "+size[0], size[0] == 4);
         assertTrue("sizeof_size size: "+size[1], size[1] == 8);
     }
@@ -990,7 +962,6 @@ public class TestH5P {
 
     @Test
     public void testH5P_sym_k() {
-        int[] version_info = {255,255,255,255};
         int[] size = {0,0};
 
         try {
@@ -1004,7 +975,10 @@ public class TestH5P {
             fcpl_id =  H5.H5Fget_create_plist(H5fid);
 
             /* Get the file's version information */
-            H5.H5Pget_version(fcpl_id, version_info);
+            H5F_info2_t finfo = H5.H5Fget_info(H5fid);
+            assertTrue("super block version: "+finfo.super_version, finfo.super_version == 0);
+            assertTrue("free-space manager version: "+finfo.free_version, finfo.free_version == 0);
+            assertTrue("shared object header version: "+finfo.sohm_version, finfo.sohm_version == 0);
             H5.H5Pget_sym_k(fcpl_id, size);
             deleteH5file();
         }
@@ -1012,10 +986,6 @@ public class TestH5P {
             err.printStackTrace();
             fail("H5Pget_sym_k: " + err);
         }
-        assertTrue("super block version: "+version_info[0], version_info[0] == 0);
-        assertTrue("global freelist version: "+version_info[1], version_info[1] == 0);
-        assertTrue("symbol table version: "+version_info[2], version_info[2] == 0);
-        assertTrue("shared object header version: "+version_info[3], version_info[3] == 0);
         assertTrue("symbol table tree rank: "+size[0], size[0] == 32);
         assertTrue("symbol table node size: "+size[1], size[1] == 8);
     }
@@ -1027,7 +997,6 @@ public class TestH5P {
 
     @Test
     public void testH5P_istore_k() {
-        int[] version_info = {255,255,255,255};
         int[] size = {0};
 
         try {
@@ -1041,7 +1010,10 @@ public class TestH5P {
             fcpl_id =  H5.H5Fget_create_plist(H5fid);
 
             /* Get the file's version information */
-            H5.H5Pget_version(fcpl_id, version_info);
+            H5F_info2_t finfo = H5.H5Fget_info(H5fid);
+            assertTrue("super block version: "+finfo.super_version, finfo.super_version == 1);
+            assertTrue("free-space manager version: "+finfo.free_version, finfo.free_version == 0);
+            assertTrue("shared object header version: "+finfo.sohm_version, finfo.sohm_version == 0);
             H5.H5Pget_istore_k(fcpl_id, size);
             deleteH5file();
         }
@@ -1049,10 +1021,6 @@ public class TestH5P {
             err.printStackTrace();
             fail("H5Pget_sym_k: " + err);
         }
-        assertTrue("super block version: "+version_info[0], version_info[0] == 1);
-        assertTrue("global freelist version: "+version_info[1], version_info[1] == 0);
-        assertTrue("symbol table version: "+version_info[2], version_info[2] == 0);
-        assertTrue("shared object header version: "+version_info[3], version_info[3] == 0);
         assertTrue("chunked storage b-tree 1/2-rank: "+size[0], size[0] == 64);
     }
 
@@ -1205,12 +1173,12 @@ public class TestH5P {
             strategy = H5.H5Pget_file_space_strategy(fcpl_id, persist, threshold);
             assertTrue("strategy(default): "+strategy, strategy == HDF5Constants.H5F_FSPACE_STRATEGY_FSM_AGGR);
             assertTrue("persist(default): "+persist[0], persist[0] == false);
-            assertTrue("theshold(default): "+threshold[0], threshold[0] == 1);
+            assertTrue("threshold(default): "+threshold[0], threshold[0] == 1);
             H5.H5Pset_file_space_strategy(fcpl_id, HDF5Constants.H5F_FSPACE_STRATEGY_PAGE, true, 1);
             strategy = H5.H5Pget_file_space_strategy(fcpl_id, persist, threshold);
             assertTrue("strategy: "+strategy, strategy == HDF5Constants.H5F_FSPACE_STRATEGY_PAGE);
             assertTrue("persist: "+persist[0], persist[0] == true);
-            assertTrue("theshold: "+threshold[0], threshold[0] == 1);
+            assertTrue("threshold: "+threshold[0], threshold[0] == 1);
         }
         catch (Throwable err) {
             err.printStackTrace();
