@@ -1237,9 +1237,10 @@ h5_set_info_object(void)
                 valp++;
 
             /* copy key/value pair into temporary buffer */
-            len     = strcspn(valp, ";");
-            next    = &valp[len];
-            key_val = (char *)HDcalloc(1, len + 1);
+            len  = HDstrcspn(valp, ";");
+            next = &valp[len];
+            if (NULL == (key_val = (char *)HDcalloc(1, len + 1)))
+                return -1;
 
             /* increment the next pointer past the terminating semicolon */
             if (*next == ';')
@@ -1635,6 +1636,9 @@ h5_make_local_copy(const char *origfilename, const char *local_copy_name)
     void *      buf      = NULL;                                 /* Buffer for copying data */
     const char *filename = H5_get_srcdir_filename(origfilename); /* Get the test file name to copy */
 
+    if (!filename)
+        goto error;
+
     /* Allocate copy buffer */
     if (NULL == (buf = HDcalloc((size_t)1, (size_t)READ_BUF_SIZE)))
         goto error;
@@ -1824,7 +1828,7 @@ h5_send_message(const char *send, const char *arg1, const char *arg2)
  *              signal file from disk, and only continues once it has
  *              successfully done so (i.e., only after another process has
  *              called the "h5_send_message" function to write the signal file).
- *              This functon will then immediately remove the file (i.e.,
+ *              This function will then immediately remove the file (i.e.,
  *              to indicate that it has been received and can be reused),
  *              and then exits, allowing the calling function to continue.
  *
