@@ -75,7 +75,7 @@ const char *FILENAME[] = {"filepaged", NULL};
  *              Any data mis-matches or failures reported by the HDF5
  *              library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -120,28 +120,28 @@ create_file(char *filename, hid_t fcpl, hid_t fapl)
 
     for (i = 0; i < NUM_DSETS; i++) {
 
-        HDsprintf(dset_name, "D1dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "D1dset%d", i);
         if ((dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, filespace, H5P_DEFAULT, dcpl,
                                   H5P_DEFAULT)) < 0)
             FAIL_STACK_ERROR;
         if (H5Dclose(dset_id) < 0)
             FAIL_STACK_ERROR;
 
-        HDsprintf(dset_name, "D2dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "D2dset%d", i);
         if ((dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, filespace, H5P_DEFAULT, dcpl,
                                   H5P_DEFAULT)) < 0)
             FAIL_STACK_ERROR;
         if (H5Dclose(dset_id) < 0)
             FAIL_STACK_ERROR;
 
-        HDsprintf(dset_name, "D3dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "D3dset%d", i);
         if ((dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, filespace, H5P_DEFAULT, dcpl,
                                   H5P_DEFAULT)) < 0)
             FAIL_STACK_ERROR;
         if (H5Dclose(dset_id) < 0)
             FAIL_STACK_ERROR;
 
-        HDsprintf(dset_name, "dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "dset%d", i);
         if ((dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, filespace, H5P_DEFAULT, dcpl,
                                   H5P_DEFAULT)) < 0)
             FAIL_STACK_ERROR;
@@ -166,13 +166,13 @@ create_file(char *filename, hid_t fcpl, hid_t fapl)
             }
         }
 
-        HDsprintf(dset_name, "D1dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "D1dset%d", i);
         if (H5Ldelete(grp_id, dset_name, H5P_DEFAULT) < 0)
             FAIL_STACK_ERROR;
-        HDsprintf(dset_name, "D2dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "D2dset%d", i);
         if (H5Ldelete(grp_id, dset_name, H5P_DEFAULT) < 0)
             FAIL_STACK_ERROR;
-        HDsprintf(dset_name, "D3dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "D3dset%d", i);
         if (H5Ldelete(grp_id, dset_name, H5P_DEFAULT) < 0)
             FAIL_STACK_ERROR;
     }
@@ -215,7 +215,7 @@ error:
  *              Any data mis-matches or failures reported by the HDF5
  *              library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -259,7 +259,7 @@ open_file(char *filename, hid_t fapl, hsize_t page_size, size_t page_buffer_size
 
     for (i = 0; i < NUM_DSETS; i++) {
 
-        HDsprintf(dset_name, "dset%d", i);
+        HDsnprintf(dset_name, sizeof(dset_name), "dset%d", i);
         if ((dset_id = H5Dopen2(grp_id, dset_name, H5P_DEFAULT)) < 0)
             FAIL_STACK_ERROR;
 
@@ -375,7 +375,7 @@ error:
  *              Any data mis-matches or unexpected failures or successes
  *              reported by the HDF5 library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -549,7 +549,7 @@ error:
  *              Any data mis-matches or failures reported by the HDF5
  *              library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -827,7 +827,7 @@ error:
  *              Any data mis-matches or failures reported by the HDF5
  *              library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -1081,7 +1081,7 @@ error:
  *              Any data mis-matches or failures reported by the HDF5
  *              library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -1502,7 +1502,7 @@ test_min_threshold(hid_t orig_fapl, const char *env_h5_drvr)
     if (f->shared->page_buf->raw_count != 2)
         TEST_ERROR;
 
-    /* adding more meta entires should replace meta entries since raw data
+    /* adding more meta entries should replace meta entries since raw data
      * is at its minimum
      */
     if (H5F_block_write(f, H5FD_MEM_SUPER, meta_addr + (sizeof(int) * 600), sizeof(int) * 100, data) < 0)
@@ -1517,7 +1517,7 @@ test_min_threshold(hid_t orig_fapl, const char *env_h5_drvr)
     if (f->shared->page_buf->raw_count != 2)
         TEST_ERROR;
 
-    /* bring existing raw entires up the LRU */
+    /* bring existing raw entries up the LRU */
     if (H5F_block_read(f, H5FD_MEM_DRAW, raw_addr + (sizeof(int) * 750), sizeof(int) * 100, data) < 0)
         FAIL_STACK_ERROR;
 
@@ -1533,7 +1533,7 @@ test_min_threshold(hid_t orig_fapl, const char *env_h5_drvr)
     if (f->shared->page_buf->raw_count != 3)
         TEST_ERROR;
 
-    /* adding 2 meta entries should replace 2 entires at the bottom of the LRU */
+    /* adding 2 meta entries should replace 2 entries at the bottom of the LRU */
     if (H5F_block_read(f, H5FD_MEM_SUPER, meta_addr + (sizeof(int) * 98), sizeof(int) * 100, data) < 0)
         FAIL_STACK_ERROR;
 
@@ -1716,7 +1716,7 @@ error:
  *              Any data mis-matches or failures reported by the HDF5
  *              library result in test failure.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
@@ -2019,7 +2019,7 @@ error:
  *              At present, page buffering should be disabled in parallel
  *              builds.  Verify this.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  John Mainzer
@@ -2134,7 +2134,7 @@ error:
  *
  * Purpose:     Main function for the page buffer tests.
  *
- * Return:      0 if test is sucessful
+ * Return:      0 if test is successful
  *              1 if test fails
  *
  * Programmer:  unknown
