@@ -244,7 +244,7 @@ jserr_str(const char *expected, const char *actual, const char *reason)
     }
 
 #ifdef JSVERIFY_EXP_ACT
-/* VERIFY rountines with paramter order (<expected>, <actual> [, <msg> ])
+/* VERIFY routines with parameter order (<expected>, <actual> [, <msg> ])
  */
 
 /*----------------------------------------------------------------------------
@@ -435,7 +435,7 @@ error:
  *
  * Purpose:
  *
- *     Demonstrate the construction of a Canoncial Request (and Signed Headers)
+ *     Demonstrate the construction of a Canonical Request (and Signed Headers)
  *
  *     Elided / not yet implemented:
  *         Query strings
@@ -730,7 +730,7 @@ test_hrb_init_request(void)
             FALSE,
         },
         {
-            "null verb substitues to GET",
+            "null verb substitutes to GET",
             NULL,
             "/MYPATH/MYFILE.tiff",
             "/MYPATH/MYFILE.tiff",
@@ -1143,10 +1143,10 @@ test_hrb_node_set(void)
          *********/
 
         for (mock_i = 0; test->given[mock_i] != NULL; mock_i += 2) {
-            const char *name = test->given[mock_i];
-            const char *valu = test->given[mock_i + 1];
+            const char *name  = test->given[mock_i];
+            const char *value = test->given[mock_i + 1];
 
-            FAIL_IF(SUCCEED != H5FD_s3comms_hrb_node_set(&list, name, valu))
+            FAIL_IF(SUCCEED != H5FD_s3comms_hrb_node_set(&list, name, value))
         }
         /********
          * TEST *
@@ -1162,11 +1162,11 @@ test_hrb_node_set(void)
         node   = list;
         mock_i = 0;
         while (test->expected[mock_i] != NULL && node != NULL) {
-            const char *name = test->expected[mock_i];
-            const char *valu = test->expected[mock_i + 1];
+            const char *name  = test->expected[mock_i];
+            const char *value = test->expected[mock_i + 1];
 
             JSVERIFY_STR(name, node->name, NULL)
-            JSVERIFY_STR(valu, node->value, NULL)
+            JSVERIFY_STR(value, node->value, NULL)
 
             mock_i += 2;
             node = node->next;
@@ -1559,7 +1559,7 @@ test_parse_url(void)
                 NULL,
                 "a=b&d=b",
             },
-            "QUERY with implict PATH",
+            "QUERY with implicit PATH",
         },
         {
             "http://[5]/path?a=b&d=b",
@@ -2014,7 +2014,7 @@ error:
  *     H5FD_s3comms_s3r_read    << called by getsize(), multiple times working
  *     H5FD_s3comms_s3r_close
  *
- *     Shows most basic curl interation.
+ *     Shows most basic curl iteration.
  *
  * Programmer: Jacob Smith
  *             2017-10-06
@@ -2610,7 +2610,7 @@ main(void)
 
     bucket_url_env = HDgetenv("HDF5_ROS3_TEST_BUCKET_URL");
     if (bucket_url_env == NULL || bucket_url_env[0] == '\0') {
-        HDprintf("WARNING: S3 bucket url is not defined in enviornment "
+        HDprintf("WARNING: S3 bucket url is not defined in environment "
                  "variable 'HDF5_ROS3_TEST_BUCKET_URL'!\n");
     }
     else {
@@ -2618,7 +2618,7 @@ main(void)
         s3_test_bucket_defined = TRUE;
     }
 
-    /* tests ordered rougly by dependence */
+    /* tests ordered roughly by dependence */
     nerrors += test_macro_format_credential() < 0 ? 1 : 0;
     nerrors += test_trim() < 0 ? 1 : 0;
     nerrors += test_nlowercase() < 0 ? 1 : 0;
