@@ -306,11 +306,23 @@ diff_datasetid(hid_t did1, hid_t did2, const char *obj1_name, const char *obj2_n
      *-------------------------------------------------------------------------
      */
     H5TOOLS_DEBUG("check for memory type and sizes");
-    if ((m_tid1 = H5Tget_native_type(f_tid1, H5T_DIR_DEFAULT)) < 0)
-        H5TOOLS_GOTO_ERROR(H5DIFF_ERR, "H5Tget_native_type first ftype failed");
+    if (H5Tget_class(f_tid1) == H5T_REFERENCE) {
+        if ((m_tid1 = H5Tcopy(H5T_STD_REF)) < 0)
+            H5TOOLS_GOTO_ERROR(H5DIFF_ERR, "H5Tcopy(H5T_STD_REF) first ftype failed");
+    }
+    else {
+        if ((m_tid1 = H5Tget_native_type(f_tid1, H5T_DIR_DEFAULT)) < 0)
+            H5TOOLS_GOTO_ERROR(H5DIFF_ERR, "H5Tget_native_type first ftype failed");
+    }
 
-    if ((m_tid2 = H5Tget_native_type(f_tid2, H5T_DIR_DEFAULT)) < 0)
-        H5TOOLS_GOTO_ERROR(H5DIFF_ERR, "H5Tget_native_type second ftype failed");
+    if (H5Tget_class(f_tid2) == H5T_REFERENCE) {
+        if ((m_tid2 = H5Tcopy(H5T_STD_REF)) < 0)
+            H5TOOLS_GOTO_ERROR(H5DIFF_ERR, "H5Tcopy(H5T_STD_REF) second ftype failed");
+    }
+    else {
+        if ((m_tid2 = H5Tget_native_type(f_tid2, H5T_DIR_DEFAULT)) < 0)
+            H5TOOLS_GOTO_ERROR(H5DIFF_ERR, "H5Tget_native_type second ftype failed");
+    }
 
     m_size1 = H5Tget_size(m_tid1);
     m_size2 = H5Tget_size(m_tid2);
@@ -462,10 +474,10 @@ diff_datasetid(hid_t did1, hid_t did2, const char *obj1_name, const char *obj2_n
             /* reclaim any VL memory, if necessary */
             H5TOOLS_DEBUG("check vl_data1:%d", vl_data1);
             if (vl_data1)
-                H5Dvlen_reclaim(m_tid1, sid1, H5P_DEFAULT, buf1);
+                H5Treclaim(m_tid1, sid1, H5P_DEFAULT, buf1);
             H5TOOLS_DEBUG("check vl_data2:%d", vl_data2);
             if (vl_data2)
-                H5Dvlen_reclaim(m_tid2, sid2, H5P_DEFAULT, buf2);
+                H5Treclaim(m_tid2, sid2, H5P_DEFAULT, buf2);
             if (buf1 != NULL) {
                 HDfree(buf1);
                 buf1 = NULL;
@@ -508,14 +520,14 @@ diff_datasetid(hid_t did1, hid_t did2, const char *obj1_name, const char *obj2_n
             if (buf1 != NULL) {
                 /* reclaim any VL memory, if necessary */
                 if (vl_data1)
-                    H5Dvlen_reclaim(m_tid1, sid1, H5P_DEFAULT, buf1);
+                    H5Treclaim(m_tid1, sid1, H5P_DEFAULT, buf1);
                 HDfree(buf1);
                 buf1 = NULL;
             }
             if (buf2 != NULL) {
                 /* reclaim any VL memory, if necessary */
                 if (vl_data2)
-                    H5Dvlen_reclaim(m_tid2, sid2, H5P_DEFAULT, buf2);
+                    H5Treclaim(m_tid2, sid2, H5P_DEFAULT, buf2);
                 HDfree(buf2);
                 buf2 = NULL;
             }
@@ -797,14 +809,14 @@ diff_datasetid(hid_t did1, hid_t did2, const char *obj1_name, const char *obj2_n
                 if (sm_buf1 != NULL) {
                     /* reclaim any VL memory, if necessary */
                     if (vl_data1)
-                        H5Dvlen_reclaim(m_tid1, sm_space1, H5P_DEFAULT, sm_buf1);
+                        H5Treclaim(m_tid1, sm_space1, H5P_DEFAULT, sm_buf1);
                     HDfree(sm_buf1);
                     sm_buf1 = NULL;
                 }
                 if (sm_buf2 != NULL) {
                     /* reclaim any VL memory, if necessary */
                     if (vl_data2)
-                        H5Dvlen_reclaim(m_tid2, sm_space2, H5P_DEFAULT, sm_buf2);
+                        H5Treclaim(m_tid2, sm_space2, H5P_DEFAULT, sm_buf2);
                     HDfree(sm_buf2);
                     sm_buf2 = NULL;
                 }
@@ -877,14 +889,14 @@ done:
     if (buf1 != NULL) {
         /* reclaim any VL memory, if necessary */
         if (vl_data1)
-            H5Dvlen_reclaim(m_tid1, sid1, H5P_DEFAULT, buf1);
+            H5Treclaim(m_tid1, sid1, H5P_DEFAULT, buf1);
         HDfree(buf1);
         buf1 = NULL;
     }
     if (buf2 != NULL) {
         /* reclaim any VL memory, if necessary */
         if (vl_data2)
-            H5Dvlen_reclaim(m_tid2, sid2, H5P_DEFAULT, buf2);
+            H5Treclaim(m_tid2, sid2, H5P_DEFAULT, buf2);
         HDfree(buf2);
         buf2 = NULL;
     }
@@ -892,14 +904,14 @@ done:
     if (sm_buf1 != NULL) {
         /* reclaim any VL memory, if necessary */
         if (vl_data1)
-            H5Dvlen_reclaim(m_tid1, sm_space1, H5P_DEFAULT, sm_buf1);
+            H5Treclaim(m_tid1, sm_space1, H5P_DEFAULT, sm_buf1);
         HDfree(sm_buf1);
         sm_buf1 = NULL;
     }
     if (sm_buf2 != NULL) {
         /* reclaim any VL memory, if necessary */
         if (vl_data2)
-            H5Dvlen_reclaim(m_tid2, sm_space2, H5P_DEFAULT, sm_buf2);
+            H5Treclaim(m_tid2, sm_space2, H5P_DEFAULT, sm_buf2);
         HDfree(sm_buf2);
         sm_buf2 = NULL;
     }
