@@ -21,10 +21,6 @@
 
 #include "H5public.h" /* Include Public Definitions    */
 
-/*
- * Include ANSI-C header files.
- */
-#ifdef H5_STDC_HEADERS
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
@@ -37,7 +33,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#endif
 
 /* maximum of two, three, or four values */
 #undef MAX
@@ -478,37 +473,27 @@ extern char *         strdup(const char *s);
 #define TRUE true
 #endif
 
-/** From h5test.h **/
-
-#ifdef H5_HAVE_PARALLEL
-extern MPI_Info h5_io_info_g; /* MPI INFO object for IO */
-#endif
-
-#ifdef H5_HAVE_PARALLEL
-int  h5_set_info_object(void);
-void h5_dump_info_object(MPI_Info info);
-#endif
-
 /** From h5tools_utils.h **/
 
 extern int         opt_err; /* getoption prints errors if this is on    */
 extern int         opt_ind; /* token pointer                            */
 extern const char *opt_arg; /* flag argument (or value)                 */
 
-enum {
+enum h5_arg_level {
     no_arg = 0,  /* doesn't take an argument     */
     require_arg, /* requires an argument          */
     optional_arg /* argument is optional         */
 };
 
-typedef struct long_options {
-    const char *name;     /* name of the long option              */
-    int         has_arg;  /* whether we should look for an arg    */
-    char        shortval; /* the shortname equivalent of long arg
-                           * this gets returned from get_option   */
-} long_options;
+struct long_options {
+    const char *      name;     /* Name of the long option */
+    enum h5_arg_level has_arg;  /* Whether we should look for an arg */
+    char              shortval; /* The shortname equivalent of long arg
+                                 * this gets returned from get_option
+                                 */
+};
 
-extern int get_option(int argc, const char **argv, const char *opt, const struct long_options *l_opt);
+extern int get_option(int argc, const char *const *argv, const char *opt, const struct long_options *l_opt);
 
 extern int nCols; /*max number of columns for outputting  */
 
